<template>
  <NutForm
    :model-value="form"
    ref="formRef"
    :rules="rules"
    label-position="top"
    class="order-bill-recharge phone chunk-form"
  >
    <NutFormItem label="姓名" class="bole-form-item" prop="name" required>
      <NutInput
        v-model.trim="form.name"
        class="bole-input-text"
        placeholder="请填写您的姓名"
        type="text"
      />
    </NutFormItem>
    <NutFormItem label="联系方式" class="bole-form-item" prop="phoneNumber" required>
      <NutInput
        v-model.trim="form.phoneNumber"
        class="bole-input-text"
        placeholder="请填写您的联系方式"
        type="text"
      />
    </NutFormItem>
  </NutForm>
</template>

<script setup lang="ts">
import { Form as NutForm, FormItem as NutFormItem, Input as NutInput } from '@nutui/nutui-taro';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { reactive, ref } from 'vue';
import { useLifeRechargeContext } from '@life-payment/core-vue';
import { FormValidator } from '../../utils';

defineOptions({
  name: 'ApplyAgentView',
});

const emit = defineEmits<{
  (e: 'submit'): void;
}>();

const form = reactive({
  name: '',
  phoneNumber: '',
});

const rules = reactive<FormRules>({
  name: [{ required: true, message: '请填写您的姓名' }],
  phoneNumber: [
    { required: true, message: '请填写您的联系方式' },
    { validator: FormValidator.validatorPhoneNumber, message: '请输入正确的手机号' },
  ],
});

const { blLifeRecharge } = useLifeRechargeContext();

const formRef = ref<any>(null);

function handleSubmit() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      refundUserLifePayOrder();
    }
  });
}

async function refundUserLifePayOrder() {
  try {
    // let params = {
    //   userId: blLifeRecharge.accountModel.userId,
    //   refundApplyRemark: form.refundApplyRemark,
    // };
    // let res = await blLifeRecharge.services.refundUserLifePayOrder(params);
    emit('submit');
  } catch (error) {}
}

defineExpose({
  handleSubmit,
});
</script>
